@@ -11,9 +11,9 @@
 
 package Minecraft::RCON;
 
-our $VERSION = '1.010_04';
+our $VERSION = '1.01';
 
-use 5.008;
+use 5.010;
 use strict;
 use warnings;
 no warnings 'uninitialized';
@@ -255,7 +255,7 @@ sub _recv_decode {
         $frags++;
     }
 
-    croak 'Packet too short. ' . length . ' < 10' if 10 > length;
+    croak 'Packet too short. ' . length($_) . ' < 10' if 10 > length($_);
     croak "Received packet missing terminator" unless s/\0\0$//;
 
     $size, unpack 'V!V(A*)';
@@ -271,7 +271,7 @@ Minecraft::RCON - RCON remote console communication with Minecraft servers
 
 =head1 VERSION
 
-Version 1.010_01
+Version 1.01
 
 =head1 SYNOPSIS
 
